import React from 'react'
import * as Yup from 'yup';
import { useState } from 'react';
import { useFormik, Form, FormikProvider } from 'formik';
// import { useNavigate } from 'react-router-dom';
import { Icon } from '@iconify/react';

import { 
    Stack, TextField, IconButton, InputAdornment, 
    Backdrop, CircularProgress,
} from '@mui/material';

import eyeFill from '@iconify/icons-eva/eye-fill';
import eyeOffFill from '@iconify/icons-eva/eye-off-fill';
import { Toaster } from 'react-hot-toast';
// import { V1, V2 } from '../../Utils/HTTP'

export function RegisterForm() {

    // const navigate = useNavigate();
    const [showPassword, setShowPassword] = useState(false);
    const [open, setOpen] = React.useState(false);
    const handleClose = () => {
        setOpen(false);
    };
    
    // let navigate = useNavigate()

    const RegisterSchema = Yup.object().shape({
        firstName: Yup.string()
        .min(2, 'Demasiado corto!')
        .max(50, 'Demasiado largo!')
        .required('Tu nombre es requerido'),
        lastName: Yup.string().min(2, 'Demasiado corto!').max(50, 'Demasiado Largo!').required('El apellido es requerido'),
        email: Yup.string().email('El correo no es valido').required('Email es requerido'),
        password: Yup.string().min(5, 'La contraseña debe contener mínimo 5 caracteres').required('la contraseña es requerida'),
        password_confirm: Yup.string().required('Las contraseñas no coincidien').oneOf([Yup.ref('password'), null], 'Las contraseñas no coincidien')
    });

    const formik = useFormik({

        initialValues: {
            firstName: '',
            lastName: '',
            email: '',
            password: '',
            password_confirm: ''
        },
        validationSchema: RegisterSchema,
        onSubmit: async (values) => {
            // setOpen(true);
            let body = {
                nombre : values.firstName,
                apelidos : values.lastName,
                email : values.email,
                username : values.email,
                pwd : values.password,
                "nit": "5345435",
                "cui": "555555",
                "direccio": "4 calle zona 1",
                "fechacumple": "2021-01-01",
                "telefono" : "45435345",
            }

            let url = 'http://204.48.25.93:8081/registro'
            console.log(body, url)
            // let url = 'http://psicoadmin.ditca.org:8081/registro'
            // V1(url, body);
            // V2(url, body);
            setOpen(false)
            //
        }

    });

    const { errors, touched, handleSubmit, getFieldProps } = formik;

    return (
        <FormikProvider style={{ padding : 15 }} value={formik}>
            <Form autoComplete="off" noValidate onSubmit={handleSubmit}>
                <Stack spacing={3}>
                    <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>
                        <TextField
                            label="Nombre"
                            fullWidth
                            {...getFieldProps('firstName')}
                            error={Boolean(touched.firstName && errors.firstName)}
                            helperText={touched.firstName && errors.firstName}
                        />

                        <TextField
                            label="Apellidos"
                            fullWidth
                            {...getFieldProps('lastName')}
                            error={Boolean(touched.lastName && errors.lastName)}
                            helperText={touched.lastName && errors.lastName}
                        />
                    </Stack>

                    <TextField
                        fullWidth
                        autoComplete="username"
                        type="email"
                        label="Correo Electrónico"
                        {...getFieldProps('email')}
                        error={Boolean(touched.email && errors.email)}
                        helperText={touched.email && errors.email}
                    />

                    <TextField
                        fullWidth
                        autoComplete="current-password"
                        type={showPassword ? 'text' : 'password'}
                        label="Contraseña"
                        {...getFieldProps('password')}
                        InputProps={{
                            endAdornment: (
                                <InputAdornment position="end">
                                    <IconButton edge="end" onClick={() => setShowPassword((prev) => !prev)}>
                                        <Icon icon={showPassword ? eyeFill : eyeOffFill} />
                                    </IconButton>
                                </InputAdornment>
                            )
                        }}
                        error={Boolean(touched.password && errors.password)}
                        helperText={touched.password && errors.password}
                    />

                    <TextField
                        fullWidth
                        type={showPassword ? 'text' : 'password'}
                        label="Confirma contraseña"
                        {...getFieldProps('password_confirm')}
                        InputProps={{
                            endAdornment: (
                                <InputAdornment position="end">
                                    <IconButton edge="end" onClick={() => setShowPassword((prev) => !prev)}>
                                        <Icon icon={showPassword ? eyeFill : eyeOffFill} />
                                    </IconButton>
                                </InputAdornment>
                            )
                        }}
                        error={Boolean(touched.password_confirm && errors.password_confirm)}
                        helperText={touched.password_confirm && errors.password_confirm}
                    />


        {/*
            <Button 
            type="submit"
            size="large"
            style={{ backgroundColor : '#d32f2f'}}
            variant="contained" >
            Registrarme
            </Button>
            */
        }

                </Stack>
            </Form>
            <Toaster
                position="top-left"
                reverseOrder={false}
            />
            <Backdrop
                sx={{ color: '#fd4b4b', zIndex: (theme) => theme.zIndex.drawer + 1 }}
                open={open}
                onClick={handleClose}
            >
                <CircularProgress color="inherit" />
            </Backdrop>
        </FormikProvider>
    );
}
