import * as React from 'react';
import { Link as RouterLink } from 'react-router-dom';

import { styled } from '@mui/material/styles';
import { 
    Box, Card, Link, Container, Typography,
    StepLabel,Step,Stepper, Button,Paper, StepContent
} from '@mui/material';

import Page from '../Components/Register/Page';
import { RegisterForm } from '../Components/Register/RegisterForm';
import { PersonalInfo } from '../Components/Register/PersonalInfo.js';
import AuthLayout from '../Components/Register/AuthLayout';

import Mock from  '../Images/register_mok.png'
import useAuth from '../Auth/useAuth';
import { useNavigate } from 'react-router-dom'

const RootStyle = styled(Page)(({ theme }) => ({
    [theme.breakpoints.up('md')]: {
        display: 'flex'
    }
}));

const SectionStyle = styled(Card)(({ theme }) => ({
    width: '100%',
    maxWidth: 464,
    display: 'flex',
    flexDirection: 'column',
    justifyContent: 'center',
    margin: theme.spacing(2, 0, 2, 2)
}));

const ContentStyle = styled('div')(({ theme }) => ({
    maxWidth: 480,
    margin: 'auto',
    display: 'flex',
    minHeight: '100vh',
    flexDirection: 'column',
    justifyContent: 'center',
    padding: theme.spacing(12, 0)
}));

const steps = [
    {
        label: 'Información de tu cuenta',
        description: <RegisterForm/>
    }, {
        label: 'Datos Personales',
        description: <PersonalInfo/>
    },
];

export function Register() {

    let auth = useAuth();
    let navigate = useNavigate()

    React.useEffect(() => {
        if(auth.isLogged()){
            return navigate('/dashboard/home')
        }    
    }, [auth,navigate])

    const [activeStep, setActiveStep] = React.useState(0);

    const handleNext = () => {
        setActiveStep((prevActiveStep) => prevActiveStep + 1);
    };

    const handleBack = () => {
        setActiveStep((prevActiveStep) => prevActiveStep - 1);
    };

    const handleReset = () => {
        setActiveStep(0);
    };

    return (
        <RootStyle title="Register | Minimal-UI">

            <AuthLayout>
                Ya tiene una cuenta?&nbsp;
                <Link to="/login" component={RouterLink}>
                    Ingresa
                </Link>
            </AuthLayout>

            <SectionStyle>
                <Typography variant="h3" sx={{ px: 5, mt: 10, mb: 5 }}>
                    Efectividad para tus procesos de reclutamiento
                </Typography>
                <img alt="register" src={Mock} />
            </SectionStyle>

            <Container>
                <ContentStyle>
                    <Box sx={{ mb: 5 }}>
                        <Typography variant="h4" gutterBottom>
                            Empieza de forma gratuita.
                        </Typography>
                        <Typography sx={{ color: 'text.secondary' }}>
                            Gratis para siempre. No se necesita tarjeta de crédito.
                        </Typography>
                    </Box>


                    <Stepper activeStep={activeStep} orientation="vertical">
    {steps.map((step, index) => (
          <Step key={step.label}>
            <StepLabel
              optional={
                index === 2 ? (
                  <Typography variant="caption">Last step</Typography>
                ) : null
              }
            >
              {step.label}
            </StepLabel>
        <StepContent style={{ padding : 25}}>
              {step.description}
              <Box sx={{ mb: 2 }}>
                <div style={{ paddingTop  : 15}}>
                  <Button
                    variant="contained"
                    onClick={handleNext}
                    sx={{ mt: 1, mr: 1 }}
                  >
                    {index === steps.length - 1 ? 'Registrarme' : 'Siguiente'}
                  </Button>
                  <Button
                    disabled={index === 0}
                    onClick={handleBack}
                    sx={{ mt: 1, mr: 1 }}
                  >
                    Regresar
                  </Button>
                </div>
              </Box>
            </StepContent>
          </Step>
        ))}                    
                    </Stepper>
 {activeStep === steps.length && (
        <Paper square elevation={0} sx={{ p: 3 }}>
          <Typography>All steps completed - you&apos;re finished</Typography>
          <Button onClick={handleReset} sx={{ mt: 1, mr: 1 }}>
            Reset
          </Button>
        </Paper>
      )}

        <Typography variant="body2" align="center" sx={{ color: 'text.secondary', mt: 3 }}>
        Estoy de acuerdo con las {" "}
        <Link underline="always" sx={{ color: "#d32f2f" }}>
        Condiciones de servicio
        </Link>
        {" "}y{" "}
        <Link underline="always" sx={{ color: "#d32f2f" }}>
        Política de privacidad
                        </Link>
                        .
                    </Typography>

                    <div>
                        <Typography variant="subtitle2" sx={{ mt: 3, textAlign: 'center' }}>
                            Ya tiene una cuenta?&nbsp;
                            <Link to="/login" component={RouterLink}>
                                Ingresa
                            </Link>
                        </Typography>
                    </div>
                </ContentStyle>
            </Container>
        </RootStyle>
    );
}
